Installation
============

Tomotok is available from python package index. It can be installed using pip by running command::

    pip install tomotok

If pip is not available it can be installed using files downloaded from a `github repository <https://github.com/Tomotok>`_ by running command::

    python setup.py install

in the folder with the source code.